<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>HeadersFootersViewerPrivate</name>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/headersfootersviewerprivate.ui" line="14"/>
        <source>Headers and Footers Editor</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UserBase</name>
    <message>
        <location filename="../../plugins/usermanagerplugin/database/userbase.cpp" line="257"/>
        <location filename="../../plugins/usermanagerplugin/database/userbase.cpp" line="280"/>
        <location filename="../../plugins/usermanagerplugin/database/userbase.cpp" line="303"/>
        <source>ERROR : will retreiving %1. Wrong number of fields</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/database/userbase.cpp" line="448"/>
        <location filename="../../plugins/usermanagerplugin/database/userbase.cpp" line="473"/>
        <source>Can not create a new user&apos;s UUID, database access error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/database/userbase.cpp" line="511"/>
        <source>Trying to create empty user database. 
Location : %1 
FileName: %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/database/userbase.cpp" line="599"/>
        <source>User database created : File %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/database/userbase.cpp" line="645"/>
        <location filename="../../plugins/usermanagerplugin/database/userbase.cpp" line="791"/>
        <source>Unable to open database %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/database/userbase.cpp" line="718"/>
        <source>User %1 correctly updated.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UserManagerPlugin</name>
    <message>
        <location filename="../../plugins/usermanagerplugin/usermanagerplugin.cpp" line="82"/>
        <source>You can pursue with this user or connect with another one.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/usermanagerplugin.cpp" line="84"/>
        <source>Stay connected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/usermanagerplugin.cpp" line="85"/>
        <source>Change the current user</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UserPlugin::Internal::CurrentUserPreferencesWidget</name>
    <message>
        <location filename="../../plugins/usermanagerplugin/currentuserpreferenceswidget.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/currentuserpreferenceswidget.ui" line="32"/>
        <source>User preferences</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UserPlugin::Internal::UserBase</name>
    <message>
        <location filename="../../plugins/usermanagerplugin/database/userbase.cpp" line="626"/>
        <source>Recorded User Last Login : %1 </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UserPlugin::Internal::UserIdentifier</name>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/useridentifier.ui" line="14"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/useridentifier.ui" line="26"/>
        <source>appName</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/useridentifier.ui" line="42"/>
        <source>User identification</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/useridentifier.ui" line="59"/>
        <source>Informations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/useridentifier.ui" line="71"/>
        <source>Identifiers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/useridentifier.ui" line="77"/>
        <source>Login</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/useridentifier.ui" line="84"/>
        <source>Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/useridentifier.ui" line="100"/>
        <source>Remember me for a while</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/useridentifier.ui" line="135"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:13pt; font-weight:600; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;The users&apos; database has been created.&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Use &lt;span style=&quot; font-style:italic;&quot;&gt;admin&lt;/span&gt; for the login and password.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/useridentifier.cpp" line="133"/>
        <source>Incorrect login/password informations.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/useridentifier.cpp" line="134"/>
        <source>You can try %1 more time(s).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/useridentifier.cpp" line="138"/>
        <source>User is identified.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/useridentifier.cpp" line="146"/>
        <source>User is not identified.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UserPlugin::Internal::UserManager</name>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/usermanager.ui" line="14"/>
        <source>MainWindow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/usermanager.ui" line="34"/>
        <source>Memory Usage</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/usermanager.ui" line="40"/>
        <source>TextLabel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/usermanager.ui" line="57"/>
        <source>User Manager Tool Bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/usermanager.ui" line="77"/>
        <source>Create new user</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/usermanager.ui" line="82"/>
        <source>Modify User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/usermanager.ui" line="87"/>
        <source>Save changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/usermanager.ui" line="92"/>
        <source>Clear modifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/usermanager.ui" line="97"/>
        <location filename="../../plugins/usermanagerplugin/widgets/usermanager.ui" line="100"/>
        <source>Delete User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/usermanager.ui" line="105"/>
        <location filename="../../plugins/usermanagerplugin/widgets/usermanager.ui" line="108"/>
        <source>Quit User Manager</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UserPlugin::Internal::UserManagerPrivate</name>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/usermanager.cpp" line="322"/>
        <source>Database usage : %1,
Memory usage : %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/usermanager.cpp" line="372"/>
        <source>No user created</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/usermanager.cpp" line="376"/>
        <source>User created</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/usermanager.cpp" line="385"/>
        <source>Modifications cleared</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/usermanager.cpp" line="387"/>
        <source>Can not clear modifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/usermanager.cpp" line="398"/>
        <source>User saved</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/usermanager.cpp" line="404"/>
        <source>User deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/usermanager.cpp" line="406"/>
        <source>User can not be deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/usermanager.cpp" line="424"/>
        <location filename="../../plugins/usermanagerplugin/widgets/usermanager.cpp" line="440"/>
        <source>User Manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/usermanager.cpp" line="431"/>
        <location filename="../../plugins/usermanagerplugin/widgets/usermanager.cpp" line="435"/>
        <source>Search user by name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/usermanager.cpp" line="432"/>
        <location filename="../../plugins/usermanagerplugin/widgets/usermanager.cpp" line="436"/>
        <source>Search user by firstname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/usermanager.cpp" line="433"/>
        <location filename="../../plugins/usermanagerplugin/widgets/usermanager.cpp" line="437"/>
        <source>Search user by name and firstname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/usermanager.cpp" line="434"/>
        <location filename="../../plugins/usermanagerplugin/widgets/usermanager.cpp" line="438"/>
        <source>Search user by city</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/usermanager.cpp" line="439"/>
        <source>Search a user</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UserPlugin::Internal::UserPasswordDialog</name>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userpassworddialog.ui" line="14"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userpassworddialog.ui" line="32"/>
        <source>Change your password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userpassworddialog.ui" line="49"/>
        <source>Type old password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userpassworddialog.ui" line="56"/>
        <source>Type new password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userpassworddialog.ui" line="63"/>
        <source>Confirm new password</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UserPlugin::Internal::UserRightsModel</name>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userrightswidget.cpp" line="164"/>
        <source>No Rights</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userrightswidget.cpp" line="165"/>
        <source>All Rights</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userrightswidget.cpp" line="166"/>
        <source>Can read own datas</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userrightswidget.cpp" line="167"/>
        <source>Can read delegates datas</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userrightswidget.cpp" line="168"/>
        <source>Can read all datas</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userrightswidget.cpp" line="169"/>
        <source>Can write own datas</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userrightswidget.cpp" line="170"/>
        <source>Can write delegates datas</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userrightswidget.cpp" line="171"/>
        <source>Can write all datas</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userrightswidget.cpp" line="172"/>
        <source>Can print</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userrightswidget.cpp" line="173"/>
        <source>Can create new datas</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userrightswidget.cpp" line="174"/>
        <source>Can delete datas</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UserPlugin::Internal::UserViewer</name>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userviewer.ui" line="14"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userviewer.ui" line="40"/>
        <source>Identity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userviewer.ui" line="57"/>
        <source>Login</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userviewer.ui" line="67"/>
        <source>View login history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userviewer.ui" line="74"/>
        <source>Change password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userviewer.ui" line="81"/>
        <source>Last Login</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userviewer.ui" line="97"/>
        <source>Date and time of the last connection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userviewer.ui" line="113"/>
        <source>Unique Identifant</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userviewer.ui" line="130"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userviewer.ui" line="140"/>
        <source>Second Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userviewer.ui" line="150"/>
        <source>Firstname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userviewer.ui" line="160"/>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userviewer.ui" line="170"/>
        <source>Gender</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userviewer.ui" line="196"/>
        <source>Contact</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userviewer.ui" line="204"/>
        <source>Country</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userviewer.ui" line="216"/>
        <source>Language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userviewer.ui" line="228"/>
        <source>Address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userviewer.ui" line="238"/>
        <source>ZipCode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userviewer.ui" line="248"/>
        <source>City</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userviewer.ui" line="258"/>
        <source>Tel 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userviewer.ui" line="270"/>
        <source>Tel 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userviewer.ui" line="282"/>
        <source>Tel 3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userviewer.ui" line="294"/>
        <source>Fax</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userviewer.ui" line="306"/>
        <source>Mail</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userviewer.ui" line="332"/>
        <source>Datas</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userviewer.ui" line="348"/>
        <source>Specialties and qualifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userviewer.ui" line="364"/>
        <source>Specialty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userviewer.ui" line="374"/>
        <source>Qualifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userviewer.ui" line="387"/>
        <source>Practitioner identifiant</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userviewer.ui" line="420"/>
        <location filename="../../plugins/usermanagerplugin/widgets/userviewer.ui" line="434"/>
        <source>Rights</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userviewer.ui" line="456"/>
        <source>User manager rights</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userviewer.ui" line="472"/>
        <source>Medical rights</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userviewer.ui" line="494"/>
        <source>Drugs dosage rights</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userviewer.ui" line="513"/>
        <source>Paramedical rights</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userviewer.ui" line="529"/>
        <source>Administrative rights</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userviewer.ui" line="546"/>
        <source>Headers and Footers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userviewer.ui" line="561"/>
        <source>Generic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userviewer.ui" line="571"/>
        <source>Administrative</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userviewer.ui" line="581"/>
        <source>Prescriptions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userviewer.ui" line="597"/>
        <source>Alerts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userviewer.ui" line="615"/>
        <source>Only super-administrator can leave alerts to users.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UserPlugin::Internal::UserViewerPrivate</name>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userviewer.cpp" line="125"/>
        <source>You can not access to these datas.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userviewer.cpp" line="125"/>
        <source>You don&apos;t have these rights.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userviewer.cpp" line="284"/>
        <source>Login history.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userviewer.cpp" line="285"/>
        <source>User %1
Last connection : %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UserPlugin::UserAdressPage</name>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="396"/>
        <source>Please enter your complete adress.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="397"/>
        <source>This represents your professional address.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="398"/>
        <source>Address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="399"/>
        <source>City</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="400"/>
        <source>Zipcode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="401"/>
        <source>Country</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UserPlugin::UserIdentityPage</name>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="287"/>
        <source>Please enter your identity.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="288"/>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="289"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="290"/>
        <source>Firstname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="327"/>
        <source>All users must have at least a name and a firstname.
You can not poursue with an anonymous user.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="291"/>
        <source>Second Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="292"/>
        <source>Gender</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="326"/>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="329"/>
        <source>Forbidden anonymous user.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UserPlugin::UserLanguageSelectorPage</name>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="252"/>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="281"/>
        <source>Language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="276"/>
        <source>Please set your language.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="277"/>
        <source>Whole application will be translated to this language, forms too (when possible).
For instance, FreeMedForms is available in few languages.
New translations are planned.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UserPlugin::UserLoginPasswordPage</name>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="338"/>
        <source>Please enter your login and password.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="339"/>
        <source>Login</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="340"/>
        <source>Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="341"/>
        <source>Confirm Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="372"/>
        <source>Wrong password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="376"/>
        <source>Login error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="378"/>
        <source>Wrong login</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="384"/>
        <source>Login and password already used</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="387"/>
        <source>Login/Password already used</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="370"/>
        <source>Password confirmation error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="371"/>
        <source>You must correctly confirm your password to go throw this page.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="377"/>
        <source>You must specify a valid login. Empty login is forbidden.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="385"/>
        <source>The users&apos; database already contains the same login/password couple.
You must specify a different login/password.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UserPlugin::UserManager</name>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/usermanager.cpp" line="145"/>
        <source>You&apos;ve modified the users&apos; list.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/usermanager.cpp" line="145"/>
        <source>Do you want to save your changes ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/usermanager.cpp" line="153"/>
        <source>Changes have been correctly saved.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/usermanager.cpp" line="157"/>
        <source>Changes can not be correctly saved.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UserPlugin::UserManagerPlugin</name>
    <message>
        <location filename="../../plugins/usermanagerplugin/usermanagerplugin.cpp" line="136"/>
        <source>User is not identified.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/usermanagerplugin.cpp" line="207"/>
        <source>Change current user</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UserPlugin::UserModel</name>
    <message>
        <location filename="../../plugins/usermanagerplugin/usermodel.cpp" line="281"/>
        <source>Unable to retreive user into the model using login and password.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/usermodel.cpp" line="292"/>
        <source>Setting current user uuid to %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/usermodel.cpp" line="376"/>
        <source>Default user can not be deleted from database.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/usermodel.cpp" line="377"/>
        <source>User can not be deleted.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/usermodel.cpp" line="378"/>
        <source>You can not delete super-administrator user.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/usermodel.cpp" line="379"/>
        <source>The super-administrator user is defined by default, if you want to protect access to the super-administrator you&apos;d better change its password.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/usermodel.cpp" line="390"/>
        <source>You can not delete a modified user, save it before.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/usermodel.cpp" line="401"/>
        <source>User can not be deleted from database.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UserPlugin::UserPaperPage</name>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="614"/>
        <source>Generic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="616"/>
        <source>Prescription</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="618"/>
        <source>Administrative</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="619"/>
        <source>%1 headers and footers</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UserPlugin::UserPasswordDialog</name>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userpassworddialog.cpp" line="116"/>
        <source>The old password is not correct. Please retry with the correct password.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userpassworddialog.cpp" line="118"/>
        <source>Wrong password confirmation.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userpassworddialog.cpp" line="119"/>
        <source>Password can not be change.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UserPlugin::UserProfilPage</name>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="471"/>
        <source>Select a profil</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="472"/>
        <source>FreeMedForms allows you to create users using predefined profils. Select your profil and options.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="482"/>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="513"/>
        <source>Software administrator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="489"/>
        <source>Define all rights</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UserPlugin::UserRightsPage</name>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="557"/>
        <source>Define user&apos;s rights.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="558"/>
        <source>Role by role, define the user&apos;s rights.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="568"/>
        <source>Users</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="569"/>
        <source>Drugs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="570"/>
        <source>Medicals</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="571"/>
        <source>Paramedicals</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="572"/>
        <source>Administrative</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UserPlugin::UserSpecialiesQualificationsPage</name>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="527"/>
        <source>Define user&apos;s specialties and qualifications.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="528"/>
        <source>Use the context menu to add, remove, move up or down items.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="541"/>
        <source>Specialities</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="542"/>
        <source>Qualifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="543"/>
        <source>Identifiants</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UserPlugin::UserTelsAndMailPage</name>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="428"/>
        <source>Please, enter tels, fax and mail adress.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="429"/>
        <source>Tel1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="430"/>
        <source>Tel2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="431"/>
        <source>Tel3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="432"/>
        <source>Fax</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="433"/>
        <source>Mail</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UserPlugin::UserWizard</name>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="123"/>
        <source>User Creator Wizard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="139"/>
        <source>Data losing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="136"/>
        <source>WARNING ! You don&apos;t save this user.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="137"/>
        <source>If you continue changes will be lost.
Do you really want to close this dialog ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="148"/>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="229"/>
        <source>An error occured during database access.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="149"/>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="230"/>
        <source>Logged errors saved. Please refer to the %1 to manage this error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="151"/>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="232"/>
        <source>Error during database access</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="221"/>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="224"/>
        <source>User correctly saved into database.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/usermanagerplugin/widgets/userwizard.cpp" line="222"/>
        <source>You can poursue with the current user %1 or set this new user to current user.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>tkUser</name>
    <message>
        <location filename="../../plugins/usermanagerplugin/userdata.cpp" line="789"/>
        <source>User logged at %1
</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
